@@ -312,7 +312,7 @@ int vk_req(xmlDocPtr reqXml, xmlDocPtr doc, msa_module* info)
 int make_request(xmlDocPtr reqXml, xmlDocPtr doc, char* remixmid, char* remixsid)
 {
     gchar* converted_friends = NULL;
-    char* tmp;
+    char* tmp = NULL;
     char* url;
     char* class = get_req_class(reqXml);
     char* function = get_req_function(reqXml);
@@ -1089,6 +1089,7 @@ int http_get(const char* url, const char* proxy, long port, char** header, char*
 
     if (curl_easy_perform(c) != 0) {
         fprintf(stderr, "Can't perform the request\n");
+        curl_easy_cleanup(c);
         return 400;
     }
 
@@ -1096,7 +1097,7 @@ int http_get(const char* url, const char* proxy, long port, char** header, char*
     curl_easy_getinfo(c, CURLINFO_RESPONSE_CODE, &code );
     g_debug("CODE %d", code);
 
-    type2 = malloc(sizeof(char)*50);
+    //type2 = g_malloc(sizeof(char)*50);
     curl_easy_getinfo(c, CURLINFO_CONTENT_TYPE, &type2 );
     g_debug("TYPE %s", type2);
 
@@ -1117,10 +1118,12 @@ int http_get(const char* url, const char* proxy, long port, char** header, char*
     }
     if(chunk.memory)
         free(chunk.memory);
-    //free(type2);
+
     //g_print("CONTENT  %s\n", *body);
 
+    //g_free(type2);
     curl_easy_cleanup(c);
+
     return code;
 }
 
