@@ -232,8 +232,7 @@ int parser_profile(xmlDocPtr doc, char* json, char* remixmid)
         tm_date.tm_year = json_object_get_int(buf) - 1900;
         //json_object_put(buf);
 	
-        char* date;
-        date = malloc(sizeof(char)*11);
+        char* date = malloc(sizeof(char)*11);
         strftime(date, 11, "%d.%m.%Y\0", &tm_date);
 
         node = xmlNewDocNode(doc, NULL, BAD_CAST "date", date);
